####Atrium####
#Load in packages
require(geomorph)
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Atrium/Analysis/")

AllInds<-readland.tps(file = "Atri_20190829.tps", specID = "imageID", readcurves = F)
SlidersFile<-read.csv(file = "curveslide.csv")
#SurfSlide<-seq(from = 71, to = 270, by = 1)
SurfSlide<-seq(from = 100, to = 339, by = 1)

#Procrustes, w/o duplicate LMs
IncludeSeq<-sort(c(1:99,160:169,299:308,150:159,309:318,140:149,319:328,130:139,329:338,120:129,339:348,110:119,233:242,100:109,243:252,220:229,253:262,210:219,263:272,200:209,273:282,190:199,283:292,180:189,170:179))
Y.gpa<-gpagen(A = AllInds[IncludeSeq,,-11], curves = SlidersFile, surfaces = SurfSlide)
plotTangentSpace(A = Y.gpa$coords, axis1 = 1, axis2 = 2, groups = unclass(AllData$Group))

AtrGPA_P<-Y.gpa

setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Corrs")
AllData<-read.csv("HeartPCscores.csv")
#Allometry
Y.gpa$Csize<-AllData$centroid.size[-11:-12] #Ps
Y.gpa$Csize<-AllData$centroid.size[c(-1:-4,-11,-145:-148)] #HBs
gdf <- geomorph.data.frame(Y.gpa, species = dimnames(Y.gpa$coords)[[3]])
HybAllometry <- procD.allometry(coords~Csize, data=gdf, iter=999)

plot(procD.allometry(coords~Csize, data=gdf), label = dimnames(Y.gpa$coords)[[3]])
plot(HybAllometry, method = "RegScore", label = as.character(AllData$ID), pt.col = unclass(AllData$Combine))

summary(HybAllometry)

##Obtaining size-adjusted residuals (and allometry-free shapes)##
HybAnova <- procD.lm(HybAllometry$formula, data = HybAllometry$data, iter = 999, RRPP=TRUE) 

#ANOVA Table
summary(HybAnova) 
shape.resid <- arrayspecs(HybAnova$residuals, p=dim(Y.gpa$coords)[1], k=dim(Y.gpa$coords)[2]) # size-adjusted residuals

#allometry-free shapes
AtriumShape <- shape.resid + array(Y.gpa$consensus, dim(shape.resid))


##Symmetry Analyses 
#Curves
B<-cbind(3:46,46:3)[1:22,] #anterior ring
N<-cbind(c(2,47:99),c(99:47,2))[1:27,] #posterior ring

#Surface LMs
#Left side, right side
####L#######R####
#(160:169,299:308)
A<-cbind(160:169,290:299)
S<-cbind(150:159,300:309)
D<-cbind(140:149,310:319)
G<-cbind(130:139,320:329)
H<-cbind(120:129,330:339)
J<-cbind(110:119,230:239)
K<-cbind(100:109,240:249)
L<-cbind(220:229,250:259)
Z<-cbind(210:219,260:269)
X<-cbind(200:209,270:279)
C<-cbind(190:199,280:289)
V<-cbind(180:189,170:179)

Q<-rbind(A,S,D,G,H,J,K,L,Z,X,C,V,B,N)

gdf <- geomorph.data.frame(shape = AtriumShape, ind=dimnames(AtriumShape)[[3]])
Atrium.sym <- bilat.symmetry(A = shape, ind = ind, object.sym = TRUE, 
                             land.pairs=Q, data = gdf, RRPP = TRUE, iter = 999)
summary(Atrium.sym)

#w/parents
plotTangentSpace(A = AtriumShape, axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]],groups = AllData$Group[-11])
plotTangentSpace(A = Atrium.sym$symm.shape, axis1 = 1, axis2 = 2, groups = AllData$Group[-11:-12],label = dimnames(AtriumShape)[[3]][-11:-12])
plotTangentSpace(A = Atrium.sym$symm.shape, axis1 = 1, axis2 = 2, groups = AllData$Group[c(-1:-4,-11,-145:-148)])
plotTangentSpace(A = Atrium.sym$asymm.shape, axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]])

#wo/parents
plotTangentSpace(A = AtriumShape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]][5:143])
plotTangentSpace(A = Atrium.sym$symm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]][5:143])
plotTangentSpace(A = Atrium.sym$asymm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]][5:143])

#Extract symm. component from scores
ScoresP<-plotTangentSpace(A = Atrium.sym$symm.shape, axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]])
Scores<-plotTangentSpace(A = Atrium.sym$symm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(AtriumShape)[[3]][5:143])


open3d()
mfrow3d(1, 2)
plot3d(Atrium.sym$DA.component[,,1])
plot3d(Atrium.sym$DA.component[,,2])

#Note 5009 is super thin
Scores<-plotTangentSpace(A = Atrium.sym$symm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(adj.shape)[[3]][5:143])




setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Corrs/")
Hearts<-read.csv("zHeartPCs.csv")

dimnames(Ventricle.sym$symm.shape)[[3]]<-Hearts$HybridID
dimnames(Ventricle.sym$asymm.shape)[[3]]<-Hearts$HybridID
dimnames(Atrium.sym$symm.shape)[[3]]<-Hearts$HybridID
dimnames(Atrium.sym$asymm.shape)[[3]]<-Hearts$HybridID


HeartCorrs<-two.b.pls(A1 = Atrium.sym$symm.shape, A2 = Ventricle.sym$symm.shape)
plot(HeartCorrs)
summary(HeartCorrs)
