setwd("/Users/Home/Desktop")
install.packages("/Users/Home/Desktop/geomorph_3.0.4.tar.gz", repos = NULL, type="source")
library(geomorph)

#Set WD
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Mandible/")

#Read in data and TPS file
AllInds<-readland.tps("M_20190929.tps", specID = "imageID", readcurves = F)

#Reflect specific individuals
RefInd<-c("LFxTRC5620", "LFxTRC5614", "LFxTRC5613", "LFxTRC5606", "LFxTRC5603", "LFxTRC5601", "LFxTRC5595", "LFxTRC5591", "LFxTRC5589", "LFxTRC5583", "LFxTRC5582", "LFxTRC5578", "LFxTRC5569", "LFxTRC5563", "LFxTRC5552", "LFxTRC5547", "LFxTRC5527", "LFxTRC5526", "LFxTRC5510", "LFxTRC5509", "LFxTRC5115", "LFxTRC5113", "LFxTRC5110", "LFxTRC5108", "LFxTRC5098", "LFxTRC5095", "LFxTRC5087", "LFxTRC5086", "LFxTRC5009", "TRC17-0031", "LF17-N3")
AllInds[,1,RefInd]<-AllInds[,1,RefInd]*-1

#Check data excluding reflected individuals
#NoRefInd<-dimnames(AllInds)[[3]][!dimnames(AllInds)[[3]]%in%RefInd]

setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Corrs")
AllData<-read.csv("HeartPCscores.csv")

#Procrustes
Y.gpa<-gpagen(AllInds[,,c(-1:-4,-7,-89,-147:-150)]) #remove LFxTRC5003 and LFxTRC5560

#Check for L-R discrepency
plotTangentSpace(Y.gpa$coords, axis1 = 1, axis2 = 2, label = dimnames(Y.gpa$coords)[[3]])


####Allometry####
Y.gpa$Csize<-AllData$centroid.size[c(5:144)] #HBs
gdf <- geomorph.data.frame(Y.gpa, species = dimnames(Y.gpa$coords)[[3]])
HybAllometry <- procD.allometry(coords~Csize, data=gdf, iter=999)

##Obtaining size-adjusted residuals (and allometry-free shapes)##
HybAnova <- procD.lm(HybAllometry$formula, data = HybAllometry$data, iter = 999, RRPP=TRUE) 
summary(HybAnova) 

shape.resid <- arrayspecs(HybAnova$residuals, p=dim(Y.gpa$coords)[1], k=dim(Y.gpa$coords)[2]) # size-adjusted residuals

#allometry-free shapes
MandibleShape <- shape.resid + array(Y.gpa$consensus, dim(shape.resid))

#Set up symmetric structure
#ManSym<-cbind(3:12,22:13)
ManSym<-cbind(3:11,20:12)

#Analyze asymmetry
gdf <- geomorph.data.frame(shape = MandibleShape, ind=dimnames(MandibleShape)[[3]])
Mandible.sym <- bilat.symmetry(A = shape, ind = ind, object.sym = TRUE, 
                             land.pairs=ManSym, data = gdf, RRPP = TRUE, iter = 999)
summary(Mandible.sym)


#wo/parents
par(pty='s')
plotTangentSpace(A = MandibleShape, axis1 = 1, axis2 = 2, label = dimnames(MandibleShape)[[3]])
plotTangentSpace(A = Mandible.sym$symm.shape, axis1 = 1, axis2 = 2, label = dimnames(MandibleShape)[[3]])
plotTangentSpace(A = Mandible.sym$asymm.shape, axis1 = 1, axis2 = 2, label = dimnames(MandibleShape)[[3]])

##PCA of allometry- and asymmetry-free shape##
ScoresO<-plotTangentSpace(MandibleShape)
ScoresS<-plotTangentSpace(Mandible.sym$symm.shape)
ScoresA<-plotTangentSpace(Mandible.sym$asymm.shape)

setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Mandible/")
write.csv(ScoresO$pc.scores, "ManPCScores_O.csv")
write.csv(ScoresS$pc.scores, "ManPCScores_S.csv")
write.csv(ScoresA$pc.scores, "ManPCScores_A.csv")
