####Ventricle####
#Load in packages
require(geomorph)
####Symm####
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Muscles/Hearts/GMM/Ventricle/Analysis/")

AllInds<-readland.tps(file = "Vent_20190820.tps", specID = "imageID", readcurves = F)
SlidersFile<-read.csv(file = "curveslide.csv")
SurfSlide<-seq(from = 65, to = 224, by = 1)

#Procrustes, w/o duplicate LMs
IncludeSeq<-sort(c(1:64,65:114,125:164,175:214,225:254))
Y.gpa<-gpagen(A = AllInds[IncludeSeq,,5:142], curves = SlidersFile, surfaces = SurfSlide)

#Allometry
Y.gpa$Csize<-AllData$centroid.size[c(-7,-90)]
gdf <- geomorph.data.frame(Y.gpa, species = dimnames(Y.gpa$coords)[[3]])
HybAllometry <- procD.allometry(coords~Csize, data=gdf, iter=999)

##Obtaining size-adjusted residuals (and allometry-free shapes)##
HybAnova <- procD.lm(HybAllometry$formula, data = HybAllometry$data, iter = 999, RRPP=TRUE) 

#ANOVA Table
shape.resid <- arrayspecs(HybAnova$residuals, p=dim(Y.gpa$coords)[1], k=dim(Y.gpa$coords)[2]) # size-adjusted residuals

#allometry-free shapes
VentricleShape <- shape.resid + array(Y.gpa$consensus, dim(shape.resid))

##Symmetry Analyses 
#Curves
#B<-cbind(3:64,64:3)#[1:31,] #Top ring, right
B<-cbind(3:64,64:3)[32:62,] #Top ring, left

#Surface LMs
#Left side, right side
####L#######R####
A<-cbind(185:194,175:184)
S<-cbind(215:224,165:174)
D<-cbind(205:214,155:164)
G<-cbind(195:204,145:154)
H<-cbind(105:114,135:144)
J<-cbind(95:104,125:134)
K<-cbind(85:94,115:124)
L<-cbind(75:84,65:74)

Q<-rbind(A,S,D,G,H,J,K,L,B)

gdf <- geomorph.data.frame(shape = VentricleShape, ind=dimnames(VentricleShape)[[3]])
Ventricle.sym <- bilat.symmetry(A = shape, ind = ind, object.sym = TRUE, 
                             land.pairs=Q, data = gdf, RRPP = TRUE, iter = 999)
summary(Ventricle.sym)

#w/parents
plotTangentSpace(A = VentricleShape, axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]])
plotTangentSpace(A = Ventricle.sym$symm.shape, axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]])
plotTangentSpace(A = Ventricle.sym$asymm.shape, axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]])

#wo/parents
plotTangentSpace(A = VentricleShape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]][5:143])
plotTangentSpace(A = Ventricle.sym$symm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]][5:143])
plotTangentSpace(A = Ventricle.sym$asymm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]][5:143])


#Extract symm. component from scores
ScoresP<-plotTangentSpace(A = Ventricle.sym$symm.shape, axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]])
Scores<-plotTangentSpace(A = Ventricle.sym$symm.shape[,,5:143], axis1 = 1, axis2 = 2, label = dimnames(VentricleShape)[[3]][5:143])