rm(list = ls(all = TRUE)) 
#load qtl library
library(qtl)

#load data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Atrium/")
F5All <- read.cross(format="csv",file="MQM/HeartDataQTL.csv",
                    na.strings="NA",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


gt <- geno.table(F5All)
todrop3 <- rownames(gt[gt$P.value < 1e-70,])
F5Omit <- drop.markers(F5All, todrop3)


augdata1<-fill.geno(F5Omit)

write.cross(cross = augdata1, format = "csv", filestem = "AugCrossF5_AtVtSym")

#Load aug data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Atrium/")
augdata1 <- read.cross(format="csv",file="MQM/AugCrossF5_AtVtSym.csv",
                    na.strings="-",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


####Symm####
####Atrium PC1####
scan1<-mqmscan(augdata1,pheno.col=2,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(777,674,386,697)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=60))
find.markerindex(augdata1,find.marker(augdata1,chr=20,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=12,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=21,pos=0))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=2,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=20,pos=45)
find.marker(augdata1,chr=22,pos=60)
C20P45<-effectplot(cross = F5All, pheno.col = 2, mname1 = "scaffold_12_6118322", var.flag=c("group"))
C22P60<-effectplot(cross = F5All, pheno.col = 2, mname1 = "scaffold_259_89154", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,20,qtl.index=674,prob=0.95,lodcolumn=1, expandtomarkers=T)
bayesint(homescan1,22,qtl.index=777,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=2, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Atrium PC2####
scan1<-mqmscan(augdata1,pheno.col=3,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(51,536,285)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=2,pos=20))
find.markerindex(augdata1,find.marker(augdata1,chr=16,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=8,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=1,pos=20))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=3,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=2,pos=20)
C02P20<-effectplot(cross = F5All, pheno.col = 3, mname1 = "scaffold_87_2535251", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,2,qtl.index=51,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=3, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)



####Asymm####
####Atrium PC1####
scan1<-mqmscan(augdata1,pheno.col=6,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(234,757,171)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=6,pos=0))


homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=6,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=7,pos=40)
find.marker(augdata1,chr=22,pos=40)
C07P40<-effectplot(cross = F5All, pheno.col = 6, mname1 = "scaffold_0_17182901", var.flag=c("group"))
C22P40<-effectplot(cross = F5All, pheno.col = 6, mname1 = "scaffold_238_187375", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,7,qtl.index=234,prob=0.95,lodcolumn=1, expandtomarkers=T)
bayesint(homescan1,22,qtl.index=757,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=6, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Atrium PC2####
scan1<-mqmscan(augdata1,pheno.col=7,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
#cofactorsindex <-c(78,287,151)
cofactorsindex <-c(146,521)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=8,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr=5,pos=20))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=7,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=5,pos=20)
C05P20<-effectplot(cross = F5All, pheno.col = 7, mname1 = "scaffold_58_1097399", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,5,qtl.index=151,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=7, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)




####Orig####
####Atrium PC1####
scan1<-mqmscan(augdata1,pheno.col=10,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(234,403,468,757)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=40))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=10,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=22,pos=40)
C22P40<-effectplot(cross = F5All, pheno.col = 10, mname1 = "scaffold_238_187375", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,22,qtl.index=757,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=10, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Atrium PC2####
scan1<-mqmscan(augdata1,pheno.col=11,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(241,386,227,230)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=35))
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=20))
find.markerindex(augdata1,find.marker(augdata1,chr=12,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=60))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=11,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=12,pos=0)
C12P00<-effectplot(cross = F5All, pheno.col = 11, mname1 = "scaffold_56_3640997", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,12,qtl.index=386,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=11, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)





#Auto co-factor analysis
auto.F2 <- mqmautocofactors(augdata1,50) #assigns 250 cofactors across genome accounting for marker density (10 cofactors/chromosome)
#this will be different each time you run it
homescan2<-mqmscan(cross=augdata1,cofactors=auto.F2,pheno.col=11,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
#plot(homescan2,  alternate.chrid = T)
#plot(homescan2,  chr=2)
summary(homescan2)



find.marker(augdata1,chr=15,pos=45)  #PC1 Ventricle Sym
find.marker(augdata1,chr=7,pos=5)  #PC2 Ventricle Sym
find.marker(augdata1,chr=22,pos=60) #PC2 Atrium Sym
find.marker(augdata1,chr=12,pos=50) #PC1 Atrium Sym

effectplot(cross = augdata1, pheno.col = 2, mname1 = "scaffold_259_89154", var.flag=c("group")) #chr=7
effectplot(cross = augdata1, pheno.col = 3, mname1 = "scaffold_4_4491611", var.flag=c("group")) #chr=7

effectplot(cross = augdata1, pheno.col = 4, mname1 = "scaffold_23_5084661", var.flag=c("group")) #chr=7
effectplot(cross = augdata1, pheno.col = 5, mname1 = "scaffold_155_1520985", var.flag=c("group")) #chr=21
