rm(list = ls(all = TRUE)) 
#load qtl library
library(qtl)

#load data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Cleithrum/")
F5All <- read.cross(format="csv",file="MQM/HeartDataQTL.csv",
                    na.strings="NA",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


gt <- geno.table(F5All)
todrop3 <- rownames(gt[gt$P.value < 1e-70,])
F5Omit <- drop.markers(F5All, todrop3)


augdata1<-fill.geno(F5Omit)

write.cross(cross = augdata1, format = "csv", filestem = "AugCrossF5_AtVtSym")

#Load aug data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Cleithrum/")
augdata1 <- read.cross(format="csv",file="MQM/AugCrossF5_AtVtSym.csv",
                    na.strings="-",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


####Symm####
####Cleithrum PC1####
scan1<-mqmscan(augdata1,pheno.col=14,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(772,410)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr="13a",pos=25))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=14,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=22,pos=55)
C22P55<-effectplot(cross = F5All, pheno.col = 14, mname1 = "scaffold_30_4120609", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,22,qtl.index=772,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=14, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Cleithrum PC2####
scan1<-mqmscan(augdata1,pheno.col=15,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(416,171,14,752)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr="13a",pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=20))
find.markerindex(augdata1,find.marker(augdata1,chr=1,pos=40))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=15,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr="13a",pos=40)
C13aP40<-effectplot(cross = F5All, pheno.col = 15, mname1 = "scaffold_38_2111260", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,"13a",qtl.index=416,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=15, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)



####Asymm####
####Cleithrum PC1####
scan1<-mqmscan(augdata1,pheno.col=22,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(54,213,685,617,738,162,244,110,303,159,556,690,177,472,530,140,630,63,353,49,71,224,114,100,341,536,425,608,15,487,464,82,324,380,289,669,706,774,271,695,576,633,517,157,429,760,591,478,366,76)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=11,pos=55))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=22,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=11,pos=55)
C11P55<-effectplot(cross = F5All, pheno.col = 22, mname1 = "scaffold_189_295714", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,11,qtl.index=365,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=22, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Cleithrum PC2####
scan1<-mqmscan(augdata1,pheno.col=23,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
#cofactorsindex <-c(108,159,323,520)
cofactorsindex <-c(284,732)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=8,pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=16,pos=50))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=23,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=8,pos=40)
find.marker(augdata1,chr=16,pos=50)
C08P40<-effectplot(cross = F5All, pheno.col = 23, mname1 = "scaffold_190_934937", var.flag=c("group")) #chr=7
#C16P50<-effectplot(cross = F5All, pheno.col = 23, mname1 = "scaffold_86_1495785", var.flag=c("group")) #chr=7


#Significant intervals
bayesint(homescan1,8,qtl.index=284,prob=0.95,lodcolumn=1, expandtomarkers=T)
#bayesint(homescan1,16,qtl.index=540,prob=0.95,lodcolumn=1, expandtomarkers=T)


#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=23, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)




####Orig####
####Cleithrum PC1####
scan1<-mqmscan(augdata1,pheno.col=18,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(772,410)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr="13a",pos=25))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=18,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=22,pos=55)
C22P55<-effectplot(cross = F5All, pheno.col = 18, mname1 = "scaffold_30_4120609", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,22,qtl.index=772,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=18, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Cleithrum PC2####
scan1<-mqmscan(augdata1,pheno.col=19,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(483)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=14,pos=60))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=19,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=14,pos=60.3)
C14P60<-effectplot(cross = F5All, pheno.col = 19, mname1 = "scaffold_0_1839752", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,14,qtl.index=483,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=19, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)





#Auto co-factor analysis
auto.F2 <- mqmautocofactors(augdata1,50) #assigns 250 cofactors across genome accounting for marker density (10 cofactors/chromosome)
#this will be different each time you run it
homescan2<-mqmscan(cross=augdata1,cofactors=auto.F2,pheno.col=19,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
#plot(homescan2,  alternate.chrid = T)
#plot(homescan2,  chr=2)
summary(homescan2)



find.marker(augdata1,chr=14,pos=60)  #PC1 Ventricle Sym
find.marker(augdata1,chr=7,pos=5)  #PC2 Ventricle Sym
find.marker(augdata1,chr=22,pos=60) #PC2 Atrium Sym
find.marker(augdata1,chr=12,pos=50) #PC1 Atrium Sym

effectplot(cross = augdata1, pheno.col = 19, mname1 = "scaffold_0_1839752", var.flag=c("group")) #chr=7
effectplot(cross = augdata1, pheno.col = 3, mname1 = "scaffold_4_4491611", var.flag=c("group")) #chr=7

effectplot(cross = augdata1, pheno.col = 4, mname1 = "scaffold_23_5084661", var.flag=c("group")) #chr=7
effectplot(cross = augdata1, pheno.col = 5, mname1 = "scaffold_155_1520985", var.flag=c("group")) #chr=21
