rm(list = ls(all = TRUE)) 
#load qtl library
library(qtl)

#load data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Mandible/")
F5All <- read.cross(format="csv",file="MQM/HeartDataQTL.csv",
                    na.strings="NA",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


gt <- geno.table(F5All)
todrop3 <- rownames(gt[gt$P.value < 1e-70,])
F5Omit <- drop.markers(F5All, todrop3)


augdata1<-fill.geno(F5Omit)

write.cross(cross = augdata1, format = "csv", filestem = "AugCrossF5_AtVtSym")

#Load aug data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Mandible/")
augdata1 <- read.cross(format="csv",file="MQM/AugCrossF5_AtVtSym.csv",
                    na.strings="-",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


####Symm####
####Mandible PC1####
scan1<-mqmscan(augdata1,pheno.col=16,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(156,8) #Cofact 1
cofactorsindex <-c(193,196,360,483,484) #Cofact 2
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=5,pos=35))
find.markerindex(augdata1,find.marker(augdata1,chr=1,pos=10))
find.markerindex(augdata1,find.marker(augdata1,chr=15,pos=0))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=16,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
#Co-factors 1
find.marker(augdata1,chr=5,pos=35)
C05P35<-effectplot(cross = F5All, pheno.col = 16, mname1 = "scaffold_18_4038452", var.flag=c("group"))

#Co-factors 2
find.marker(augdata1,chr=15,pos=0)
effectplot(cross = F5All, pheno.col = 16, mname1 = "scaffold_5_11506904", var.flag=c("group"))

find.marker(augdata1,chr=11,pos=55)
effectplot(cross = F5All, pheno.col = 16, mname1 = "scaffold_196_269495", var.flag=c("group"))


#Significant intervals
bayesint(homescan1,5,qtl.index=156,prob=0.95,lodcolumn=1, expandtomarkers=T)
bayesint(homescan1,15,qtl.index=484,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=16, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Mandible PC2####
scan1<-mqmscan(augdata1,pheno.col=17,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(227)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=20))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=17,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=7,pos=20)
C07P20<-effectplot(cross = F5All, pheno.col = 17, mname1 = "scaffold_21_2195347", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,7,qtl.index=227,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=17, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)



####Asymm####
####Mandible PC1####
scan1<-mqmscan(augdata1,pheno.col=24,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(375,675)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=11,pos=105))


homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=24,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=11,pos=105)
C11P105<-effectplot(cross = F5All, pheno.col = 24, mname1 = "scaffold_207_450361", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,11,qtl.index=375,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=24, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Mandible PC2####
scan1<-mqmscan(augdata1,pheno.col=25,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
#cofactorsindex <-c(78,287,151)
cofactorsindex <-c(301,677,159,41,72)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=9,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=5,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr=2,pos=10))
find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=20))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=25,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=9,pos=25)
C09P25<-effectplot(cross = F5All, pheno.col = 25, mname1 = "scaffold_13_6386857", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,9,qtl.index=301,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=25, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)




####Orig####
####Mandible PC1####
scan1<-mqmscan(augdata1,pheno.col=20,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(156,234,490)
cofactorsindex <-c(191,229,361,484,656)
cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=5,pos=35))
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=15,pos=5))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=20,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plots
find.marker(augdata1,chr=5,pos=35)
C05P35<-effectplot(cross = F5All, pheno.col = 20, mname1 = "scaffold_18_4038452", var.flag=c("group"))

find.marker(augdata1,chr=7,pos=40)
C07P40<-effectplot(cross = F5All, pheno.col = 20, mname1 = "scaffold_0_17182901", var.flag=c("group"))

find.marker(augdata1,chr=15,pos=0)
C15P00<-effectplot(cross = F5All, pheno.col = 20, mname1 = "scaffold_5_11506904", var.flag=c("group"))


#Significant intervals
bayesint(homescan1,5,qtl.index=156,prob=0.95,lodcolumn=1, expandtomarkers=T)
bayesint(homescan1,7,qtl.index=234,prob=0.95,lodcolumn=1, expandtomarkers=T)
bayesint(homescan1,15,qtl.index=490,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=20, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Mandible PC2####
scan1<-mqmscan(augdata1,pheno.col=21,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(227)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=20))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=21,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)
plot(homescan1, alternate.chrid = T)


#Effects plots
find.marker(augdata1,chr=7,pos=20)
C07P20<-effectplot(cross = F5All, pheno.col = 21, mname1 = "scaffold_21_2195347", var.flag=c("group")) #chr=7

#Significant intervals
bayesint(homescan1,7,qtl.index=227,prob=0.95,lodcolumn=1, expandtomarkers=T)

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=21, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)





#Auto co-factor analysis
auto.F2 <- mqmautocofactors(augdata1,50) #assigns 250 cofactors across genome accounting for marker density (10 cofactors/chromosome)
#this will be different each time you run it
homescan2<-mqmscan(cross=augdata1,cofactors=auto.F2,pheno.col=20,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
#plot(homescan2,  alternate.chrid = T)
#plot(homescan2,  chr=2)
summary(homescan2)



find.marker(augdata1,chr=11,pos=50)  #PC1 Ventricle Sym
find.marker(augdata1,chr=15,pos=0)  #PC2 Ventricle Sym
find.marker(augdata1,chr=22,pos=60) #PC2 Atrium Sym
find.marker(augdata1,chr=12,pos=50) #PC1 Atrium Sym

effectplot(cross = F5All, pheno.col = 16, mname1 = "scaffold_196_269495", var.flag=c("group")) #chr=7
effectplot(cross = F5All, pheno.col = 16, mname1 = "scaffold_5_11506904", var.flag=c("group")) #chr=7

effectplot(cross = augdata1, pheno.col = 4, mname1 = "scaffold_23_5084661", var.flag=c("group")) #chr=7
effectplot(cross = augdata1, pheno.col = 5, mname1 = "scaffold_155_1520985", var.flag=c("group")) #chr=21
