rm(list = ls(all = TRUE)) 
#load qtl library
library(qtl)

#load data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Atrium/MQM/")
F5All <- read.cross(format="csv",file="HeartDataQTL.csv",
                    na.strings="NA",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)

gt <- geno.table(F5All)
todrop3 <- rownames(gt[gt$P.value < 1e-70,])
F5Omit <- drop.markers(F5All, todrop3)


augdata1<-fill.geno(F5Omit)

#write.cross(cross = augdata1, format = "csv", filestem = "AugCrossF5_VeE.csv")

#Load aug data
setwd("/Users/home/Dropbox/Amherst/Post-Doc/Map/ReAnalyze/MapPhenos/Analysis/Muscles/Heart/Ventricle/MQM/")
augdata1 <- read.cross(format="csv",file="AugCrossF5_AtVtSym.csv",
                    na.strings="-",genotypes=c("AA","AB","BB"),
                    alleles=c("A","B"),convertXdata=TRUE)


####Symm####
####Ventricle PC1####
scan1<-mqmscan(augdata1,pheno.col=4,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(496)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=15,pos=45))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=4,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=15,pos=45)
C15P45<-effectplot(cross = F5All, pheno.col = 4, mname1 = "scaffold_23_5084661", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,15,qtl.index=496,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=4, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Ventricle PC2####
scan1<-mqmscan(augdata1,pheno.col=5,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(223)
cofactorsindex <-c(223,343,407)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=5))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=5,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=7,pos=5)
C07P05<-effectplot(cross = F5All, pheno.col = 5, mname1 = "scaffold_155_1520985", var.flag=c("group"))
#scaffold_124_1667602

#Significant intervals
bayesint(homescan1,7,qtl.index=223,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=5, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####ASymm####
####Ventricle PC1####
scan1<-mqmscan(augdata1,pheno.col=8,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(65,697,162,755,536,199,107)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=21,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=5,pos=65))
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=16,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=6,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=4,pos=15))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=8,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=3,pos=0)
C03P00<-effectplot(cross = F5All, pheno.col = 8, mname1 = "scaffold_126_106602", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,3,qtl.index=65,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=8, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Ventricle PC2####
scan1<-mqmscan(augdata1,pheno.col=9,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(223)
cofactorsindex <-c(69,287,603,7,689,257,521,370,718,297,78,756)
cofactorsindex <-c(69,287,603,7,689,257,521,370,718,297)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=10))
find.markerindex(augdata1,find.marker(augdata1,chr=8,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr=18,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=1,pos=5))
find.markerindex(augdata1,find.marker(augdata1,chr=20,pos=80))
find.markerindex(augdata1,find.marker(augdata1,chr=7,pos=75))
find.markerindex(augdata1,find.marker(augdata1,chr=4,pos=30))
find.markerindex(augdata1,find.marker(augdata1,chr=16,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=11,pos=65))
find.markerindex(augdata1,find.marker(augdata1,chr=21,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=9,pos=10))
find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=35))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=9,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=1,pos=5)
find.marker(augdata1,chr=20,pos=80)
C01P05<-effectplot(cross = F5All, pheno.col = 9, mname1 = "scaffold_118_848647", var.flag=c("group"))
C20P80<-effectplot(cross = F5All, pheno.col = 9, mname1 = "scaffold_181_1152863", var.flag=c("group"))
#scaffold_124_1667602

#Significant intervals
bayesint(homescan1,1,qtl.index=7,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.
bayesint(homescan1,20,qtl.index=689,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=9, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Orig####
####Ventricle PC1####
scan1<-mqmscan(augdata1,pheno.col=12,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(84,282,416)
cofactorsindex <-c(65, 71, 267, 300, 317, 457, 496, 652)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=55))
find.markerindex(augdata1,find.marker(augdata1,chr=8,pos=35))
find.markerindex(augdata1,find.marker(augdata1,chr="13a",pos=40))
find.markerindex(augdata1,find.marker(augdata1,chr=15,pos=45))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=12,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=15,pos=45)
find.marker(augdata1,chr=3,pos=55)
C15P45<-effectplot(cross = F5All, pheno.col = 12, mname1 = "scaffold_23_5084661", var.flag=c("group"))
#C03P55<-effectplot(cross = F5All, pheno.col = 12, mname1 = "scaffold_339_46552", var.flag=c("group"))

#Significant intervals
bayesint(homescan1,15,qtl.index=496,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.
bayesint(homescan1,3,qtl.index=15,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.


#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=12, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)


####Ventricle PC2####
scan1<-mqmscan(augdata1,pheno.col=13,plot=T,model="dominance")  #Step 1: scan without cofactors
summary(scan1)

cofactorsindex<-NULL
cofactorsindex <-c(118,579,651)

cofactorsindex<-cofactorsindex[-length(cofactorsindex)]

find.markerindex(augdata1,find.marker(augdata1,chr=4,pos=45))
find.markerindex(augdata1,find.marker(augdata1,chr=17,pos=30))
find.markerindex(augdata1,find.marker(augdata1,chr=19,pos=35))

homemadecofactors<-mqmsetcofactors(augdata1,cofactors=c(cofactorsindex)) #Step 3: designate cofactors for multivariate scan.

homescan1<-mqmscan(cross=augdata1,cofactors=homemadecofactors,pheno.col=13,cofactor.significance=0.02,verbose=T,plot=T,model="dominance",multicore=T) #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan1)

#Effects plot
find.marker(augdata1,chr=4,pos=45)
find.marker(augdata1,chr=17,pos=30)
find.marker(augdata1,chr=19,pos=35)
C04P45<-effectplot(cross = F5All, pheno.col = 13, mname1 = "scaffold_68_1337477", var.flag=c("group"))
C17P30<-effectplot(cross = F5All, pheno.col = 13, mname1 = "scaffold_255_535692", var.flag=c("group"))
C19P35<-effectplot(cross = F5All, pheno.col = 13, mname1 = "scaffold_3_2598256", var.flag=c("group"))
#scaffold_124_1667602

#Significant intervals
bayesint(homescan1,4,qtl.index=118,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.
bayesint(homescan1,17,qtl.index=579,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.
bayesint(homescan1,19,qtl.index=651,prob=0.95,lodcolumn=1, expandtomarkers=T) #Use this one.

#Marker significance
Atresults <- mqmpermutation(augdata1, pheno.col=13, scanfunction=mqmscan, cofactors=homemadecofactors, n.perm=1000, multicore=T, plot=F)
sig.results <- mqmprocesspermutation(Atresults)
summary(sig.results)
mqmplot.permutations(Atresults)










auto.F2 <- mqmautocofactors(augdata1,50) #assigns 250 cofactors across genome accounting for marker density (10 cofactors/chromosome)
#this will be different each time you run it
#auto.F2
homescan2<-mqmscan(cross=augdata1,cofactors=auto.F2,pheno.col=13,cofactor.significance=0.02,verbose=T,plot=T,model="dominance") #using a dominance model tests for both additive effects and dominance, i.e., AA+AB vs BB and BB+AB vs AA, default is additive only
summary(homescan2)
plot(homescan2, alternate.chrid = T)

find.marker(augdata1,chr=17,pos=30)
effectplot(cross = F5All, pheno.col = 13, mname1 = "scaffold_255_535692", var.flag=c("group"))

find.marker(augdata1,chr=19,pos=35)
effectplot(cross = F5All, pheno.col = 13, mname1 = "scaffold_3_2598256", var.flag=c("group"))





find.markerindex(augdata1,find.marker(augdata1,chr=22,pos=25))
find.markerindex(augdata1,find.marker(augdata1,chr=21,pos=10))
find.markerindex(augdata1,find.marker(augdata1,chr=19,pos=35))
find.markerindex(augdata1,find.marker(augdata1,chr=11,pos=75))
find.markerindex(augdata1,find.marker(augdata1,chr=11,pos=70))
find.markerindex(augdata1,find.marker(augdata1,chr=9,pos=15))
find.markerindex(augdata1,find.marker(augdata1,chr=3,pos=0))
find.markerindex(augdata1,find.marker(augdata1,chr=17,pos=45))